@@ -60,6 +60,8 @@ typedef struct {
   gchar   *dialog_text;
   MsgMode  mode;
   gboolean no_wrap;
+  gchar   *ok_label;
+  gchar   *cancel_label;
 } ZenityMsgData;
 
 typedef struct {
@@ -79,6 +81,7 @@ typedef struct {
   gboolean save;
   gboolean confirm_overwrite;
   gchar   *separator;
+  gchar  **filter;
 } ZenityFileData;
 
 typedef struct {
